@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -23,13 +23,13 @@ import json
 from datetime import datetime
 
 # external packages
-from PyQt5.QtTest import QTest
 from mountcontrol.alignStar import AlignStar
 from mountcontrol.convert import convertToHMS, convertToDMS
 
 # local import
 from base import transform
-from gui.utilities.toolsQtWidget import QMultiWait
+from base.transform import JNowToJ2000, J2000ToJNow
+from gui.utilities.toolsQtWidget import QMultiWait, sleepAndEvents
 from logic.modeldata.modelHandling import writeRetrofitData
 
 
@@ -222,9 +222,9 @@ class Model:
 
         isInRange = mPoint.get('errorRMS_S', 0) < self.MAX_ERROR_MODEL_POINT
         if isSuccess and isInRange:
-            raJNowS, decJNowS = transform.J2000ToJNow(mPoint['raJ2000S'],
-                                                      mPoint['decJ2000S'],
-                                                      mPoint['julianDate'])
+            raJNowS, decJNowS = J2000ToJNow(mPoint['raJ2000S'],
+                                            mPoint['decJ2000S'],
+                                            mPoint['julianDate'])
             mPoint['raJNowS'] = raJNowS
             mPoint['decJNowS'] = decJNowS
             t = f'Queued to model [{mPoint["countSequence"]:03d}]: [{mPoint}]'
@@ -260,12 +260,12 @@ class Model:
     def modelSolve(self):
         """
         modelSolve is the method called from the signal image saved and starts
-        the solving process for this image. therefore it takes the model point
+        the solving process for this image. therefore, it takes the model point
         from the queue and uses the parameters stored. if the queue is empty (
         which should be to the case), it just returns. after starting the solving
         process in a threaded way (should run in parallel to gui) it puts the
-        model point to the next queue, the result queue. in addition if the image
-        window is present, it send a signal for displaying the actual captured
+        model point to the next queue, the result queue. in addition, if the image
+        window is present, it sends a signal for displaying the actual captured
         image. it shows the actual processed point
         index in GUI
 
@@ -287,7 +287,9 @@ class Model:
         self.app.showImage.emit(mPoint["imagePath"])
         self.resultQueue.put(mPoint)
         self.log.debug(f'Queued to result [{mPoint["countSequence"]:03d}]: [{mPoint}]')
-        self.app.astrometry.solveThreading(fitsPath=mPoint["imagePath"],
+        self.app.astrometry.solveThreading(fitsPath=mPoint['imagePath'],
+                                           raHint=mPoint['raJNowM'],
+                                           decHint=mPoint['decJNowM'],
                                            updateFits=False)
         text = f'Solving  image-{mPoint["countSequence"]:03d}:  '
         text += f'path: {os.path.basename(mPoint["imagePath"])}'
@@ -299,7 +301,7 @@ class Model:
     def modelImage(self):
         """
         modelImage is the method called from the signal mount and dome slewed
-        finish and starts the imaging for the model point. therefore it takes the
+        finish and starts the imaging for the model point. therefore, it takes the
         model point from the queue and uses the parameters stored. if the queue
         is empty (which should be to the case), it just returns.
         as we are combining the reception of multiple signals for detecting that
@@ -322,18 +324,11 @@ class Model:
             self.log.error(f'Empty image queue: {t}')
             return False
 
+        while self.ui.pauseModel.property('pause'):
+            sleepAndEvents(100)
         self.log.debug('Imaging started')
         mPoint = self.imageQueue.get()
         self.collector.resetSignals()
-        while self.ui.pauseModel.property('pause'):
-            QTest.qWait(100)
-
-        self.app.camera.expose(imagePath=mPoint['imagePath'],
-                               expTime=mPoint['exposureTime'],
-                               binning=mPoint['binning'],
-                               subFrame=mPoint['subFrame'],
-                               fastReadout=mPoint['fastReadout'],
-                               focalLength=mPoint['focalLength'])
 
         mPoint['raJNowM'] = self.app.mount.obsSite.raJNow
         mPoint['decJNowM'] = self.app.mount.obsSite.decJNow
@@ -342,6 +337,16 @@ class Model:
         mPoint['siderealTime'] = self.app.mount.obsSite.timeSidereal
         mPoint['julianDate'] = self.app.mount.obsSite.timeJD
         mPoint['pierside'] = self.app.mount.obsSite.pierside
+        mPoint['raJ2000M'], mPoint['decJ2000M'] = JNowToJ2000(mPoint['raJNowM'],
+                                                              mPoint['decJNowM'],
+                                                              mPoint['julianDate'])
+
+        self.app.camera.expose(imagePath=mPoint['imagePath'],
+                               expTime=mPoint['exposureTime'],
+                               binning=mPoint['binning'],
+                               subFrame=mPoint['subFrame'],
+                               fastReadout=mPoint['fastReadout'],
+                               focalLength=mPoint['focalLength'])
 
         self.solveQueue.put(mPoint)
         self.log.debug(f'Queued to solve [{mPoint["countSequence"]:03d}]: [{mPoint}]')
@@ -390,7 +395,7 @@ class Model:
         self.imageQueue.put(mPoint)
         self.log.debug(f'Queued to image [{mPoint["countSequence"]:03d}]: [{mPoint}]')
 
-        text = 'Slewing  mount:      point in sequence: '
+        text = 'Slewing mount:       point in sequence: '
         text += f'{mPoint["countSequence"]:03d}, '
         text += f'altitude: {mPoint["altitude"]:3.0f}, '
         text += f'azimuth: {mPoint["azimuth"]:3.0f}'
@@ -591,6 +596,8 @@ class Model:
             sPoint.update(mPoint)
             sPoint['raJNowM'] = sPoint['raJNowM'].hours
             sPoint['decJNowM'] = sPoint['decJNowM'].degrees
+            sPoint['raJ2000M'] = sPoint['raJ2000M'].hours
+            sPoint['decJ2000M'] = sPoint['decJ2000M'].degrees
             sPoint['angularPosRA'] = sPoint['angularPosRA'].degrees
             sPoint['angularPosDEC'] = sPoint['angularPosDEC'].degrees
             sPoint['raJNowS'] = sPoint['raJNowS'].hours
@@ -837,7 +844,7 @@ class Model:
             return False
         else:
             self.app.message.emit('Actual model clearing, waiting 1s', 0)
-            QTest.qWait(1000)
+            sleepAndEvents(1000)
             self.app.message.emit('Actual model cleared', 0)
             self.refreshModel()
 
@@ -858,7 +865,7 @@ class Model:
         """
         astrometryApp = self.ui.astrometryDevice.currentText()
         exposureTime = self.ui.expTime.value()
-        binning = self.ui.binning.value()
+        binning = int(self.ui.binning.value())
         subFrame = self.ui.subFrame.value()
         fastReadout = self.ui.checkFastDownload.isChecked()
         focalLength = self.ui.focalLength.value()
@@ -1036,9 +1043,9 @@ class Model:
 
         obs = self.app.mount.obsSite
         timeJD = obs.timeJD
-        raJNow, decJNow = transform.J2000ToJNow(result['raJ2000S'],
-                                                result['decJ2000S'],
-                                                timeJD)
+        raJNow, decJNow = J2000ToJNow(result['raJ2000S'],
+                                      result['decJ2000S'],
+                                      timeJD)
         obs.setTargetRaDec(raJNow, decJNow)
         suc = obs.syncPositionToTarget()
         if suc:
